==> quidproquo-actionprocessor-awslambda-0.0.224.tgz: package/lib/esm/logic/dynamo/getPagedItemsOverRange.js <==
import { DynamoDBClient, QueryCommand } from '@aws-sdk/client-dynamodb';
import { lastEvaluatedKeyToString, stringToLastEvaluatedKey } from './logs';
import { createAwsClient } from '../createAwsClient';
export async function getPagedItemsOverRange(tableName, region, runtimeType, startIsoDateTime, endIsoDateTime, pageKey) {
    const dynamoDBClient = createAwsClient(DynamoDBClient, { region });
    const queryParams = {
        TableName: tableName,
        KeyConditionExpression: 'runtimeType = :runtimeType AND startedAtWithCorrelation BETWEEN :startIsoDateTime AND :endIsoDateTime',
        ExpressionAttributeValues: {
            ':runtimeType': { S: runtimeType },
            ':startIsoDateTime': { S: startIsoDateTime + '#00000000-0000-0000-0000-000000000000' },
            ':endIsoDateTime': { S: endIsoDateTime + '#ffffffff-ffff-ffff-ffff-ffffffffffff' },
        },
        ScanIndexForward: false,
    };
    if (pageKey) {
        queryParams.ExclusiveStartKey = stringToLastEvaluatedKey(pageKey);
    }
    try {
        const queryResult = await dynamoDBClient.send(new QueryCommand(queryParams));
        const items = (queryResult.Items || []).map((i) => {
            const [startedAt, correlation] = i.startedAtWithCorrelation.S?.split('#') || [];
            const metaData = {
                generic: i.generic.S || '',
                runtimeType: i.runtimeType.S,
                error: i.error?.S,
                startedAt: startedAt,
                correlation,
                moduleName: i.moduleName.S || '',
                fromCorrelation: i.fromCorrelation?.S,
                executionTimeMs: i.executionTimeMs?.N ? parseInt(i.executionTimeMs.N) : 0,
            };
            return metaData;
        });
        if (queryResult.LastEvaluatedKey) {
            const nextPageKey = lastEvaluatedKeyToString(queryResult.LastEvaluatedKey);
            // You can return the nextPageKey along with the items, so it can be used for the next query.
            return { items, nextPageKey };
        }
        else {
            return { items };
        }
    }
    catch (err) {
        console.error(`Failed to query items in the specified date range: ${err}`);
        throw err;
    }
}

==> quidproquo-actionprocessor-awslambda-0.0.242.tgz: package/lib/esm/logic/dynamo/getPagedItemsOverRange.js <==
import { DynamoDBClient, QueryCommand } from '@aws-sdk/client-dynamodb';
import { createAwsClient } from '../createAwsClient';
import { lastEvaluatedKeyToString, stringToLastEvaluatedKey } from './logs';
export async function getPagedItemsOverRange(tableName, region, runtimeType, startIsoDateTime, endIsoDateTime, pageKey) {
    const dynamoDBClient = createAwsClient(DynamoDBClient, { region });
    const queryParams = {
        TableName: tableName,
        KeyConditionExpression: 'runtimeType = :runtimeType AND startedAtWithCorrelation BETWEEN :startIsoDateTime AND :endIsoDateTime',
        ExpressionAttributeValues: {
            ':runtimeType': { S: runtimeType },
            ':startIsoDateTime': {
                S: startIsoDateTime + '#00000000-0000-0000-0000-000000000000',
            },
            ':endIsoDateTime': {
                S: endIsoDateTime + '#ffffffff-ffff-ffff-ffff-ffffffffffff',
            },
        },
        ScanIndexForward: false,
    };
    if (pageKey) {
        queryParams.ExclusiveStartKey = stringToLastEvaluatedKey(pageKey);
    }
    try {
        const queryResult = await dynamoDBClient.send(new QueryCommand(queryParams));
        const items = (queryResult.Items || []).map((i) => {
            const [startedAt, correlation] = i.startedAtWithCorrelation.S?.split('#') || [];
            const metaData = {
                generic: i.generic.S || '',
                runtimeType: i.runtimeType.S,
                error: i.error?.S,
                startedAt: startedAt,
                correlation,
                moduleName: i.moduleName.S || '',
                fromCorrelation: i.fromCorrelation?.S,
                executionTimeMs: i.executionTimeMs?.N ? parseInt(i.executionTimeMs.N) : 0,
            };
            return metaData;
        });
        if (queryResult.LastEvaluatedKey) {
            const nextPageKey = lastEvaluatedKeyToString(queryResult.LastEvaluatedKey);
            // You can return the nextPageKey along with the items, so it can be used for the next query.
            return { items, nextPageKey };
        }
        else {
            return { items };
        }
    }
    catch (err) {
        console.error(`Failed to query items in the specified date range: ${err}`);
        throw err;
    }
}
